@@ -28,6 +28,20 @@ from nb_log import nb_log_config_default
 def revision_call_handlers(self, record):  # 对logging标准模块打猴子补丁。主要是使父命名空间的handler不重复记录当前命名空间日志已有种类的handler。
     """
     重要。这可以使同名logger或父logger随意添加同种类型的handler，确保不会重复打印。
+    例如对"a"命名空间加上streamhandler，对"a.b"命名空间也加上streamhandler，则"a.b"命名空间的日志会被打印两次
+    例子如下
+
+    import logging
+
+    logger1 = logging.getLogger('a')
+    logger1.addHandler(logging.StreamHandler())
+
+    logger2 = logging.getLogger('a.b')
+    logger2.addHandler(logging.StreamHandler())
+
+    logger2.error(666)
+
+    明明只想打印一次666，结果却答应2次了。因为a.b的父命名空间的日志也加了streamhandler。
 
     :param self:
     :param record:
@@ -77,7 +91,7 @@ def revision_add_handler(self, hdlr):  # 从添加源头阻止同一个logger添
     """
     Add the specified handler to this logger.
     """
-    logging._acquireLock()
+    logging._acquireLock() # noqa
 
     try:
         """ 官方的
@@ -97,7 +111,7 @@ def revision_add_handler(self, hdlr):  # 从添加源头阻止同一个logger添
         if hdlr_type not in hdlrx_type_set:
             self.handlers.append(hdlr)
     finally:
-        logging._releaseLock()
+        logging._releaseLock() # noqa
 
 
 logging.Logger.callHandlers = revision_call_handlers  # 打猴子补丁。
@@ -192,7 +206,8 @@ class LogManager(object):
        :param log_level_int: 日志输出级别，设置为 1 2 3 4 5，分别对应原生logging.DEBUG(10)，logging.INFO(20)，logging.WARNING(30)，logging.ERROR(40),logging.CRITICAL(50)级别，现在可以直接用10 20 30 40 50了，兼容了。
        :param is_add_stream_handler: 是否打印日志到控制台
        :param do_not_use_color_handler :是否禁止使用color彩色日志
-       :param log_path: 设置存放日志的文件夹路径
+       :param log_path: 设置存放日志的文件夹路径,如果不设置，则取nb_log_config.LOG_PATH，如果配置中也没指定则自动在代码所在磁盘的根目录创建/pythonlogs文件夹，
+              非windwos下要注意账号权限问题(如果python没权限在根目录建/pythonlogs，则需要手动先创建好)
        :param log_filename: 日志的名字，仅当log_path和log_filename都不为None时候才写入到日志文件。
        :param log_file_size :日志大小，单位M，默认100M
        :param is_use_watched_file_handler_instead_of_custom_concurrent_rotating_file_handler :是否使用watched_file_handler作为文件日志，
@@ -368,7 +383,8 @@ def get_logger(name: str, *, log_level_int: int = None, is_add_stream_handler=Tr
 
        :param is_add_stream_handler: 是否打印日志到控制台
        :param do_not_use_color_handler :是否禁止使用color彩色日志
-       :param log_path: 设置存放日志的文件夹路径
+       :param log_path: 设置存放日志的文件夹路径,如果不设置，则取nb_log_config.LOG_PATH，如果配置中也没指定则自动在代码所在磁盘的根目录创建/pythonlogs文件夹，
+              非windwos下要注意账号权限问题(如果python没权限在根目录建/pythonlogs，则需要手动先创建好)
        :param log_filename: 日志的名字，仅当log_path和log_filename都不为None时候才写入到日志文件。
        :param log_file_size :日志大小，单位M，默认100M
        :param is_use_watched_file_handler_instead_of_custom_concurrent_rotating_file_handler :是否使用watched_file_handler作为文件日志，
@@ -405,6 +421,9 @@ def get_logger_with_filehanlder(name: str) -> logging.Logger:
 
 
 class LoggerMixin(object):
+    """
+    主要是生成把类名作为日志命名空间的logger，方便被混入类直接使用self.logger，不需要手动实例化get_logger。
+    """
     subclass_logger_dict = {}
 
     @property
